.. pycraf-utils:

*****************************************
Utilities (`pycraf.utils`)
*****************************************

.. currentmodule:: pycraf.utils

Introduction
============

The `~pycraf.utils` sub-package offers various helper/utility routines
used throughout `~pycraf`.

Using `pycraf.utils`
=========================


See Also
========

- `Astropy Units and Quantities package <http://docs.astropy.org/en/stable/
  units/index.html>`_, which is used extensively in pycraf.
- Astropy `~astropy.units.quantity_input` decorator.


Reference/API
=============

.. automodapi:: pycraf.utils
    :no-inheritance-diagram:
